pub type SignedMessageWithoutPrefix = JubjubBase;Expand description
Signed message value used by the circuit transcript, without any domain prefix.
Aliased Type
pub struct SignedMessageWithoutPrefix(/* private fields */);pub type SignedMessageWithoutPrefix = JubjubBase;Signed message value used by the circuit transcript, without any domain prefix.
pub struct SignedMessageWithoutPrefix(/* private fields */);