pub type Target = JubjubBase;Expand description
Lottery threshold value used by the circuit for signer eligibility checks.
Aliased Type
pub struct Target(/* private fields */);pub type Target = JubjubBase;Lottery threshold value used by the circuit for signer eligibility checks.
pub struct Target(/* private fields */);